@@ -10,6 +10,7 @@ from applitools.common import (
     RectangleSize,
     Region,
     TestResults,
+    deprecated,
     logger,
 )
 from applitools.common.geometry import Point
@@ -102,13 +103,12 @@ class SeleniumEyes(EyesBase):
     _runner = None  # type: Optional[ClassicRunner]
 
     @staticmethod
+    @deprecated.argument("viewportsize", "use `size` argument instead")
     def set_viewport_size(driver, size=None, viewportsize=None):
         # type: (AnyWebDriver, Optional[ViewPort], Optional[ViewPort]) -> None
         assert driver is not None
         if size is None and viewportsize is None:
             raise ValueError("set_viewport_size require `size` parameter")
-        if viewportsize:
-            logger.deprecation("Use `size` parameter instead")
         eyes_selenium_utils.set_viewport_size(driver, size)
 
     @staticmethod
@@ -230,6 +230,18 @@ class SeleniumEyes(EyesBase):
             self._target_element,
         )
 
+    def _match_window(self, region_provider, tag, check_settings, source):
+        # type:(RegionProvider,Text,SeleniumCheckSettings,Optional[Text])->MatchResult
+        if check_settings.values.ocr_region:
+            check_settings.values.ocr_region.process_app_output(
+                check_settings, region_provider.get_region()
+            )
+            return MatchResult(as_expected=True)
+
+        return super(SeleniumEyes, self)._match_window(
+            region_provider, tag, check_settings, source
+        )
+
     def check(self, check_settings):
         # type: (Text, SeleniumCheckSettings) -> MatchResult
         source = eyes_selenium_utils.get_check_source(self.driver)
@@ -795,11 +807,8 @@ class SeleniumEyes(EyesBase):
         try:
             dom_json = dom_capture.get_full_window_dom(self._driver)
             return dom_json
-        except Exception as e:
-            logger.warning(
-                "Exception raising during capturing DOM Json. Passing...\n "
-                "Got next error: {}".format(str(e))
-            )
+        except Exception:
+            logger.warning("dom-capture script failed, skipping it", exc_info=True)
             return None
 
     def _region_from(self, check_settings):
