@@ -1,17 +1,19 @@
 from .eyes_connector import EyesConnector
-from .render_task import RenderTask
-from .resource_cache import ResourceCache
+from .resource_cache import PutCache, ResourceCache
+from .resource_collection_task import ResourceCollectionTask
 from .running_test import RunningTest
 from .vg_task import VGTask
 from .visual_grid_eyes import VisualGridEyes
-from .visual_grid_runner import VisualGridRunner
+from .visual_grid_runner import RunnerOptions, VisualGridRunner
 
 __all__ = (
     "VGTask",
-    "RenderTask",
+    "PutCache",
     "ResourceCache",
     "VisualGridEyes",
     "EyesConnector",
     "VisualGridRunner",
+    "RunnerOptions",
     "RunningTest",
+    "ResourceCollectionTask",
 )
